.. qtutils documentation master file, created by
   sphinx-quickstart on Mon Jan 29 11:06:51 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

QtUtils
=======
QtUtils is a Python library that provides convenient tools for Python Developers creating applications using the PyQt/PySide widget library.

Utilities include those providing thread-safe access to Qt objects, simplified QSettings storage, and dynamic widget promotion when loading UI files. 
QtUtils also includes the Fugue icon set, free to use with attribution to `Yusuke Kamiyamane`_.

.. note::
   `qtutils` 3.0 dropped support for Python 2.7, PyQt4 and PySide. If you need to use these platforms, you may use `qtutils` 2.3.2 or earlier. 
   `qtutils` 2.3.2 provides an abstraction layer for PySide/PyQt4 that matches the PyQt5 API.

.. _`Yusuke Kamiyamane`: http://p.yusukekamiyamane.com/

Contents
========
.. toctree::
   :maxdepth: 1
   
   install
   invoke_in_main

   